dupin.data.logging
------------------

.. rubric:: Overview

.. py:currentmodule:: dupin.data.logging

.. autosummary::
    :nosignatures:

    Logger

.. rubric:: Details

.. automodule:: dupin.data.logging
    :members: Logger
